![WAWI logo](https://raw.githubusercontent.com/knutankv/wawi/main/wawi-logo-animated.svg)
=======================

What is wawi?
=======================
[NOT PUBLISHED YET]


Installation 
========================
Either install via PyPI as follows:

```
pip install wawi
```

or install directly from github:

```
pip install git+https://www.github.com/knutankv/wawi.git@master
```


Quick start
=======================

Examples
=======================
Examples are provided as Jupyter Notebooks in the [examples folder](https://github.com/knutankv/wawi/tree/master/examples).

References
=======================

Citation
=======================
Zenodo research entry:

Support
=======================
Please [open an issue](https://github.com/knutankv/wawi/issues/new) for support.

